@@ -1,4 +1,4 @@
-# Copyright 2001-2013 by Roger S. Bivand. 
+# Copyright 2001-2014 by Roger S. Bivand. 
 # Upgrade to sp classes February 2007
 # Added RANN April 2010
 # nn() retired 130722
@@ -12,33 +12,37 @@ knearneigh <- function(x, k=1, longlat=NULL, RANN=TRUE)
         } else longlat <- FALSE
         x <- coordinates(x)[, 1:2]
     } else if (is.null(longlat) || !is.logical(longlat)) longlat <- FALSE
-    if (!is.numeric(x)) stop("Data non-numeric")
-    if (!is.matrix(x)) stop("Data not in matrix form")
+    if (!is.numeric(x)) stop("knearneigh: data non-numeric")
+    if (!is.matrix(x)) stop("knearneigh: data not in matrix form")
     stopifnot(ncol(x) == 2)
-    if (any(is.na(x))) stop("Data include NAs")
+    if (any(is.na(x))) stop("knearneigh: data include NAs")
     if (longlat) {
         bb <- bbox(x)
         if (!.ll_sanity(bb))
-            warning("Coordinates are not geographical: longlat argument wrong")
+            warning("knearneigh: coordinates are not geographical: longlat argument wrong")
     }
     if (!is.double(x)) storage.mode(x) <- "double"
     np <- nrow(x)
     dimension <- ncol(x)
-    if (dimension != 2) stop("Only 2D data accepted")
-    if (k >= np) stop("Fewer data points than k")
-    if (RANN && !longlat && require(RANN, quietly=TRUE)) {
+    if (dimension != 2) stop("knearneigh: only 2D data accepted")
+    if (k >= np) stop("knearneigh: fewer data points than k")
+# modified 140117 to handle zerodist points
+# (previous fix only worked for pairs and k>1)
+    zd <- zerodist(SpatialPoints(x))
+    if (!(nrow(zd) == 0)) warning("knearneigh: identical points found")
+    if (RANN && !longlat && (nrow(zd) == 0) && require(RANN, quietly=TRUE)) {
 #        xx <- cbind(x, out=rep(0, nrow(x)))
 #        out <- as.matrix(nn(xx, p=k)$nn.idx)
 # nn() retired 130722
 # modified 130913 to handle zerodist points
-        zd <- zerodist(SpatialPoints(x))
-        if (nrow(zd) == 0) {
-            out <- nn2(x, x, k=k+1)$nn.idx[,-1,drop=FALSE]
-        } else {
-            out0 <- nn2(x, x, k=k+1)
-            out <- t(sapply(1:np, function(i) out0$nn.idx[i,
-                -which(out0$nn.idx[i,] == i), drop=FALSE]))
-        }
+#        zd <- zerodist(SpatialPoints(x))
+#        if (nrow(zd) == 0) {
+        out <- nn2(x, x, k=k+1)$nn.idx[,-1,drop=FALSE]
+#        } else {
+#            out0 <- nn2(x, x, k=k+1)
+#            out <- t(sapply(1:np, function(i) out0$nn.idx[i,
+#                -which(out0$nn.idx[i,] == i), drop=FALSE]))
+#        }
         dimnames(out) <- NULL
         res <- list(nn=out, np=np, k=k, dimension=dimension, x=x)
     } else {
